@@ -1306,11 +1306,6 @@ static nsresult pref_InitInitialObjects()
     "winpref.js"
 #elif defined(XP_UNIX)
     "unix.js"
-#if defined(_AIX)
-    , "aix.js"
-#endif
-#elif defined(XP_BEOS)
-    "beos.js"
 #endif
   };
 
